@@ -6,9 +6,7 @@ our $VERSION = '0.001';
 
 use base 'Test::Smoke::Poster::Base';
 
-use fallback 'inc';
-
-use JSON;
+use Test::Smoke::Util::LoadAJSON;
 
 =head1 NAME
 
@@ -59,13 +57,21 @@ sub _post_data {
     $self->log_info("Posting to %s via %s.", $self->smokedb_url, $self->poster);
     $self->log_debug("Report data: %s", my $json = $self->get_json);
 
-    my $response = eval {
-        $self->ua->post(
+    my $response = $self->ua->post(
+        $self->smokedb_url,
+        { json => $json }
+    );
+    if ( !$response->is_success ) {
+        $self->log_warn("POST failed: %s", $response->status_line);
+        die sprintf(
+            "POST to '%s' failed: %s%s\n",
             $self->smokedb_url,
-            { json => $json }
+            $response->status_line,
+            ($response->content ? sprintf(" (%s)", $response->content) : ""),
         );
-    };
-    $self->log_warn("Error posting: $@") if $@;
+    }
+
+    $self->log_debug("[CoreSmokeDB] %s", $response->content);
 
     return $response->content;
 }
